ServerInfo

Struct ServerInfo 

pub struct ServerInfo {
    pub pver: u64,
    pub info: ArkInfo,
    pub refresh_at_secs: u64,
}

Fields

pver: u64

Protocol version used for rpc protocol.

For info on protocol versions, see server_rpc module documentation.

info: ArkInfo

Server-side configuration and network parameters returned after connection.

refresh_at_secs: u64

Informations contained in this struct will be considered outdated after this timestamp.

Implementations

Source

impl ServerInfo

pub fn new(pver: u64, info: ArkInfo) -> Self

pub fn update(&mut self, info: ArkInfo)

pub fn is_outdated(&self) -> bool

Checks if the information contained in this struct is outdated.