#[repr(i32)]pub enum LightningReceiveStatus {
Created = 0,
Accepted = 1,
HtlcsReady = 2,
Settled = 3,
Canceled = 4,
}Variants
Created = 0
We have created the invoice and are awaiting the sender to start the process
Accepted = 1
The sender has setup the payment route and it’s ready to go
HtlcsReady = 2
The Ark HTLC is created and ready to be executed with the preimage
Settled = 3
The HTLCs have been executed and the payment was settled
Canceled = 4
The payment was canceled before being executed
Implementations
Sourceimpl LightningReceiveStatus
impl LightningReceiveStatus
Sourcepub fn is_valid(value: i32) -> bool
pub fn is_valid(value: i32) -> bool
Returns true if value is a variant of LightningReceiveStatus.
Sourcepub fn from_i32(value: i32) -> Option<LightningReceiveStatus>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<LightningReceiveStatus>
Use the TryFrom<i32> implementation instead
Converts an i32 to a LightningReceiveStatus, or None if value is not a valid variant.
Sourceimpl LightningReceiveStatus
impl LightningReceiveStatus
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.