#[repr(i32)]pub enum RoundParticipationStatus {
RoundPartPending = 0,
RoundPartIssued = 1,
RoundPartReleased = 2,
}Variants
RoundPartPending = 0
participation still waiting to happen
RoundPartIssued = 1
new vtxos have been issued, but not released yet
RoundPartReleased = 2
old vtxos have been forfeited and new vtxos released
Implementations
Sourceimpl RoundParticipationStatus
impl RoundParticipationStatus
Sourcepub fn is_valid(value: i32) -> bool
pub fn is_valid(value: i32) -> bool
Returns true if value is a variant of RoundParticipationStatus.
Sourcepub fn from_i32(value: i32) -> Option<RoundParticipationStatus>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<RoundParticipationStatus>
Use the TryFrom<i32> implementation instead
Converts an i32 to a RoundParticipationStatus, or None if value is not a valid variant.
Sourceimpl RoundParticipationStatus
impl RoundParticipationStatus
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.