VtxoSpendState

Enum VtxoSpendState 

#[repr(i32)]
pub enum VtxoSpendState { Unspecified = 0, Spendable = 1, Spent = 2, Unclaimed = 3, Unregistered = 4, HtlcRecvUnclaimed = 5, }
Client-relevant spend state for a user-owned VTXO.

Server-internal states (pool, forfeit, connector) are never returned; in-flight Lightning-receive HTLCs are reported as HTLC_RECV_UNCLAIMED because the client must reveal the preimage to claim them before they become spendable.

Variants



Unspecified = 0



Spendable = 1

The VTXO is available for spending.



Spent = 2

The VTXO has been spent (via round, OOR, or offboard).



Unclaimed = 3

The VTXO originates from a round but the server has not released the unlock preimage yet.



Unregistered = 4

The VTXO’s signed transaction chain has not been uploaded yet.



HtlcRecvUnclaimed = 5

The VTXO’s preimage haven’t been revealed yet

Implementations

Source

impl VtxoSpendState

pub fn is_valid(value: i32) -> bool

Returns true if value is a variant of VtxoSpendState.

pub fn from_i32(value: i32) -> Option<VtxoSpendState>

👎Deprecated:

Use the TryFrom<i32> implementation instead

Converts an i32 to a VtxoSpendState, or None if value is not a valid variant.

Source

impl VtxoSpendState

pub fn as_str_name(&self) -> &'static str

String value of the enum field names used in the ProtoBuf definition.

The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.

pub fn from_str_name(value: &str) -> Option<Self>

Creates an enum from field names used in the ProtoBuf definition.