pub struct ArkoorCosignRequest {
pub input_vtxo_id: Vec<u8>,
pub outputs: Vec<ArkoorDestination>,
pub user_pub_nonces: Vec<Vec<u8>>,
pub isolated_outputs: Vec<ArkoorDestination>,
pub use_checkpoint: bool,
pub attestation: Vec<u8>,
}Fields
input_vtxo_id: Vec<u8>outputs: Vec<ArkoorDestination>user_pub_nonces: Vec<Vec<u8>>isolated_outputs: Vec<ArkoorDestination>outputs used for dust isolation
use_checkpoint: boolattestation: Vec<u8>Trait Implementations
Sourceimpl Clone for ArkoorCosignRequest
impl Clone for ArkoorCosignRequest
Sourcefn clone(&self) -> ArkoorCosignRequest
fn clone(&self) -> ArkoorCosignRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ArkoorCosignRequest
impl Debug for ArkoorCosignRequest
Sourceimpl Default for ArkoorCosignRequest
impl Default for ArkoorCosignRequest
Sourceimpl<V: VtxoRef> From<ArkoorCosignRequest<V>> for ArkoorCosignRequest
impl<V: VtxoRef> From<ArkoorCosignRequest<V>> for ArkoorCosignRequest
Sourcefn from(v: ArkoorCosignRequest<V>) -> Self
fn from(v: ArkoorCosignRequest<V>) -> Self
Converts to this type from the input type.
Sourceimpl Message for ArkoorCosignRequest
impl Message for ArkoorCosignRequest
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for ArkoorCosignRequest
impl PartialEq for ArkoorCosignRequest
impl StructuralPartialEq for ArkoorCosignRequest
Sourceimpl TryFrom<ArkoorCosignRequest> for ArkoorCosignRequest<VtxoId>
impl TryFrom<ArkoorCosignRequest> for ArkoorCosignRequest<VtxoId>
Sourcetype Error = ConvertError
type Error = ConvertError
The type returned in the event of a conversion error.