pub struct ArkoorCosignResponse {
pub server_pub_nonces: Vec<Vec<u8>>,
pub server_partial_sigs: Vec<Vec<u8>>,
}Fields
server_pub_nonces: Vec<Vec<u8>>server_partial_sigs: Vec<Vec<u8>>Trait Implementations
Sourceimpl Clone for ArkoorCosignResponse
impl Clone for ArkoorCosignResponse
Sourcefn clone(&self) -> ArkoorCosignResponse
fn clone(&self) -> ArkoorCosignResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ArkoorCosignResponse
impl Debug for ArkoorCosignResponse
Sourceimpl Default for ArkoorCosignResponse
impl Default for ArkoorCosignResponse
impl Eq for ArkoorCosignResponse
Sourceimpl From<ArkoorCosignResponse> for ArkoorCosignResponse
impl From<ArkoorCosignResponse> for ArkoorCosignResponse
Sourcefn from(v: ArkoorCosignResponse) -> Self
fn from(v: ArkoorCosignResponse) -> Self
Converts to this type from the input type.
Sourceimpl Hash for ArkoorCosignResponse
impl Hash for ArkoorCosignResponse
Sourceimpl Message for ArkoorCosignResponse
impl Message for ArkoorCosignResponse
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for ArkoorCosignResponse
impl PartialEq for ArkoorCosignResponse
impl StructuralPartialEq for ArkoorCosignResponse
Sourceimpl TryFrom<ArkoorCosignResponse> for ArkoorCosignResponse
impl TryFrom<ArkoorCosignResponse> for ArkoorCosignResponse
Sourcetype Error = ConvertError
type Error = ConvertError
The type returned in the event of a conversion error.