pub struct ArkoorDestination {
pub total_amount: u64,
pub policy: Vec<u8>,
}Fields
total_amount: u64policy: Vec<u8>Trait Implementations
Sourceimpl Clone for ArkoorDestination
impl Clone for ArkoorDestination
Sourcefn clone(&self) -> ArkoorDestination
fn clone(&self) -> ArkoorDestination
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ArkoorDestination
impl Debug for ArkoorDestination
Sourceimpl Default for ArkoorDestination
impl Default for ArkoorDestination
impl Eq for ArkoorDestination
Sourceimpl From<ArkoorDestination> for ArkoorDestination
impl From<ArkoorDestination> for ArkoorDestination
Sourcefn from(v: ArkoorDestination) -> Self
fn from(v: ArkoorDestination) -> Self
Converts to this type from the input type.
Sourceimpl Hash for ArkoorDestination
impl Hash for ArkoorDestination
Sourceimpl Message for ArkoorDestination
impl Message for ArkoorDestination
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for ArkoorDestination
impl PartialEq for ArkoorDestination
Sourcefn eq(&self, other: &ArkoorDestination) -> bool
fn eq(&self, other: &ArkoorDestination) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ArkoorDestination
Sourceimpl TryFrom<ArkoorDestination> for ArkoorDestination
impl TryFrom<ArkoorDestination> for ArkoorDestination
Sourcetype Error = ConvertError
type Error = ConvertError
The type returned in the event of a conversion error.