pub struct BoardCosignResponse {
pub pub_nonce: Vec<u8>,
pub partial_sig: Vec<u8>,
}Fields
pub_nonce: Vec<u8>partial_sig: Vec<u8>Trait Implementations
Sourceimpl Clone for BoardCosignResponse
impl Clone for BoardCosignResponse
Sourcefn clone(&self) -> BoardCosignResponse
fn clone(&self) -> BoardCosignResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BoardCosignResponse
impl Debug for BoardCosignResponse
Sourceimpl Default for BoardCosignResponse
impl Default for BoardCosignResponse
impl Eq for BoardCosignResponse
Sourceimpl From<BoardCosignResponse> for BoardCosignResponse
impl From<BoardCosignResponse> for BoardCosignResponse
Sourcefn from(v: BoardCosignResponse) -> Self
fn from(v: BoardCosignResponse) -> Self
Converts to this type from the input type.
Sourceimpl Hash for BoardCosignResponse
impl Hash for BoardCosignResponse
Sourceimpl Message for BoardCosignResponse
impl Message for BoardCosignResponse
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for BoardCosignResponse
impl PartialEq for BoardCosignResponse
Sourcefn eq(&self, other: &BoardCosignResponse) -> bool
fn eq(&self, other: &BoardCosignResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for BoardCosignResponse
Sourceimpl TryFrom<BoardCosignResponse> for BoardCosignResponse
impl TryFrom<BoardCosignResponse> for BoardCosignResponse
Sourcetype Error = ConvertError
type Error = ConvertError
The type returned in the event of a conversion error.