pub struct CheckLightningReceiveResponse {
pub invoice: String,
pub amount_sat: u64,
pub status: i32,
pub htlc_vtxos: Vec<Vec<u8>>,
}Fields
invoice: Stringamount_sat: u64status: i32htlc_vtxos: Vec<Vec<u8>>Empty until the status is HTLCS_READY or SETTLED
Implementations
Sourceimpl CheckLightningReceiveResponse
impl CheckLightningReceiveResponse
Sourcepub fn status(&self) -> LightningReceiveStatus
pub fn status(&self) -> LightningReceiveStatus
Returns the enum value of status, or the default if the field is set to an invalid enum value.
Sourcepub fn set_status(&mut self, value: LightningReceiveStatus)
pub fn set_status(&mut self, value: LightningReceiveStatus)
Sets status to the provided enum value.