pub struct FeeSchedule {
pub board: Option<BoardFees>,
pub offboard: Option<OffboardFees>,
pub refresh: Option<RefreshFees>,
pub lightning_receive: Option<LightningReceiveFees>,
pub lightning_send: Option<LightningSendFees>,
}Fields
board: Option<BoardFees>offboard: Option<OffboardFees>refresh: Option<RefreshFees>lightning_receive: Option<LightningReceiveFees>lightning_send: Option<LightningSendFees>Trait Implementations
Sourceimpl Clone for FeeSchedule
impl Clone for FeeSchedule
Sourcefn clone(&self) -> FeeSchedule
fn clone(&self) -> FeeSchedule
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for FeeSchedule
impl Debug for FeeSchedule
Sourceimpl Default for FeeSchedule
impl Default for FeeSchedule
Sourceimpl From<FeeSchedule> for FeeSchedule
impl From<FeeSchedule> for FeeSchedule
Sourcefn from(v: FeeSchedule) -> Self
fn from(v: FeeSchedule) -> Self
Converts to this type from the input type.
Sourceimpl Message for FeeSchedule
impl Message for FeeSchedule
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for FeeSchedule
impl PartialEq for FeeSchedule
Sourcefn eq(&self, other: &FeeSchedule) -> bool
fn eq(&self, other: &FeeSchedule) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for FeeSchedule
Sourceimpl TryFrom<FeeSchedule> for FeeSchedule
impl TryFrom<FeeSchedule> for FeeSchedule
Sourcetype Error = ConvertError
type Error = ConvertError
The type returned in the event of a conversion error.