pub struct ForfeitNoncesRequest {
pub unlock_hash: Vec<u8>,
pub vtxo_ids: Vec<Vec<u8>>,
}Fields
unlock_hash: Vec<u8>the unlock hash to forfeit to, this is the unlock hash that locks the new output VTXO
vtxo_ids: Vec<Vec<u8>>the VTXO IDs of the VTXOs to be forfeited for the same unlock preimage