HandshakeResponse

Struct HandshakeResponse 

pub struct HandshakeResponse {
    pub min_protocol_version: u64,
    pub max_protocol_version: u64,
    pub psa: Option<String>,
}

Fields

min_protocol_version: u64max_protocol_version: u64psa: Option<String>

Public Service Announcement, a generalized message from the server to be displayed to the user.

Implementations

Source

impl HandshakeResponse

pub fn psa(&self) -> &str

Returns the value of psa, or the default value if psa is unset.