pub struct LeafVtxoCosignResponse {
pub public_nonce: Vec<u8>,
pub partial_signature: Vec<u8>,
}Fields
public_nonce: Vec<u8>partial_signature: Vec<u8>Trait Implementations
Sourceimpl Clone for LeafVtxoCosignResponse
impl Clone for LeafVtxoCosignResponse
Sourcefn clone(&self) -> LeafVtxoCosignResponse
fn clone(&self) -> LeafVtxoCosignResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for LeafVtxoCosignResponse
impl Debug for LeafVtxoCosignResponse
Sourceimpl Default for LeafVtxoCosignResponse
impl Default for LeafVtxoCosignResponse
impl Eq for LeafVtxoCosignResponse
Sourceimpl From<LeafVtxoCosignResponse> for LeafVtxoCosignResponse
impl From<LeafVtxoCosignResponse> for LeafVtxoCosignResponse
Sourcefn from(v: LeafVtxoCosignResponse) -> Self
fn from(v: LeafVtxoCosignResponse) -> Self
Converts to this type from the input type.
Sourceimpl Hash for LeafVtxoCosignResponse
impl Hash for LeafVtxoCosignResponse
Sourceimpl Message for LeafVtxoCosignResponse
impl Message for LeafVtxoCosignResponse
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for LeafVtxoCosignResponse
impl PartialEq for LeafVtxoCosignResponse
impl StructuralPartialEq for LeafVtxoCosignResponse
Sourceimpl TryFrom<LeafVtxoCosignResponse> for LeafVtxoCosignResponse
impl TryFrom<LeafVtxoCosignResponse> for LeafVtxoCosignResponse
Sourcetype Error = ConvertError
type Error = ConvertError
The type returned in the event of a conversion error.