pub struct LightningReceiveFees {
pub base_fee_sat: u64,
pub ppm: u64,
}Fields
base_fee_sat: u64ppm: u64Trait Implementations
Sourceimpl Clone for LightningReceiveFees
impl Clone for LightningReceiveFees
Sourcefn clone(&self) -> LightningReceiveFees
fn clone(&self) -> LightningReceiveFees
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for LightningReceiveFees
Sourceimpl Debug for LightningReceiveFees
impl Debug for LightningReceiveFees
Sourceimpl Default for LightningReceiveFees
impl Default for LightningReceiveFees
impl Eq for LightningReceiveFees
Sourceimpl From<LightningReceiveFees> for LightningReceiveFees
impl From<LightningReceiveFees> for LightningReceiveFees
Sourcefn from(v: LightningReceiveFees) -> Self
fn from(v: LightningReceiveFees) -> Self
Converts to this type from the input type.
Sourceimpl From<LightningReceiveFees> for LightningReceiveFees
impl From<LightningReceiveFees> for LightningReceiveFees
Sourcefn from(v: LightningReceiveFees) -> Self
fn from(v: LightningReceiveFees) -> Self
Converts to this type from the input type.
Sourceimpl Hash for LightningReceiveFees
impl Hash for LightningReceiveFees
Sourceimpl Message for LightningReceiveFees
impl Message for LightningReceiveFees
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for LightningReceiveFees
impl PartialEq for LightningReceiveFees
Sourcefn eq(&self, other: &LightningReceiveFees) -> bool
fn eq(&self, other: &LightningReceiveFees) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for LightningReceiveFees