pub struct PrepareOffboardRequest {
pub offboard: Option<OffboardRequest>,
pub input_vtxo_ids: Vec<Vec<u8>>,
pub attestation: Vec<Vec<u8>>,
}Fields
offboard: Option<OffboardRequest>input_vtxo_ids: Vec<Vec<u8>>attestation: Vec<Vec<u8>>Trait Implementations
Sourceimpl Clone for PrepareOffboardRequest
impl Clone for PrepareOffboardRequest
Sourcefn clone(&self) -> PrepareOffboardRequest
fn clone(&self) -> PrepareOffboardRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PrepareOffboardRequest
impl Debug for PrepareOffboardRequest
Sourceimpl Default for PrepareOffboardRequest
impl Default for PrepareOffboardRequest
impl Eq for PrepareOffboardRequest
Sourceimpl Hash for PrepareOffboardRequest
impl Hash for PrepareOffboardRequest
Sourceimpl Message for PrepareOffboardRequest
impl Message for PrepareOffboardRequest
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for PrepareOffboardRequest
impl PartialEq for PrepareOffboardRequest
Sourcefn eq(&self, other: &PrepareOffboardRequest) -> bool
fn eq(&self, other: &PrepareOffboardRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for PrepareOffboardRequest