pub struct RefreshFees {
pub base_fee_sat: u64,
pub ppm_expiry_table: Vec<PpmExpiryFeeEntry>,
}Fields
base_fee_sat: u64ppm_expiry_table: Vec<PpmExpiryFeeEntry>Trait Implementations
Sourceimpl Clone for RefreshFees
impl Clone for RefreshFees
Sourcefn clone(&self) -> RefreshFees
fn clone(&self) -> RefreshFees
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RefreshFees
impl Debug for RefreshFees
Sourceimpl Default for RefreshFees
impl Default for RefreshFees
Sourceimpl From<RefreshFees> for RefreshFees
impl From<RefreshFees> for RefreshFees
Sourcefn from(v: RefreshFees) -> Self
fn from(v: RefreshFees) -> Self
Converts to this type from the input type.
Sourceimpl From<RefreshFees> for RefreshFees
impl From<RefreshFees> for RefreshFees
Sourcefn from(v: RefreshFees) -> Self
fn from(v: RefreshFees) -> Self
Converts to this type from the input type.
Sourceimpl Message for RefreshFees
impl Message for RefreshFees
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for RefreshFees
impl PartialEq for RefreshFees
impl StructuralPartialEq for RefreshFees