pub struct RoundEvent {
pub event: Option<Event>,
}Fields
event: Option<Event>Trait Implementations
Sourceimpl Clone for RoundEvent
impl Clone for RoundEvent
Sourcefn clone(&self) -> RoundEvent
fn clone(&self) -> RoundEvent
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RoundEvent
impl Debug for RoundEvent
Sourceimpl Default for RoundEvent
impl Default for RoundEvent
Sourceimpl<'a> From<&'a RoundEvent> for RoundEvent
impl<'a> From<&'a RoundEvent> for RoundEvent
Sourcefn from(e: &'a RoundEvent) -> Self
fn from(e: &'a RoundEvent) -> Self
Converts to this type from the input type.
Sourceimpl Hash for RoundEvent
impl Hash for RoundEvent
Sourceimpl Message for RoundEvent
impl Message for RoundEvent
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for RoundEvent
impl PartialEq for RoundEvent
Sourceimpl TryFrom<RoundEvent> for RoundEvent
impl TryFrom<RoundEvent> for RoundEvent
Sourcetype Error = ConvertError
type Error = ConvertError
The type returned in the event of a conversion error.
Sourcefn try_from(m: RoundEvent) -> Result<RoundEvent, Self::Error>
fn try_from(m: RoundEvent) -> Result<RoundEvent, Self::Error>
Performs the conversion.
impl Eq for RoundEvent
impl StructuralPartialEq for RoundEvent