RoundParticipationRequest

Struct RoundParticipationRequest 

pub struct RoundParticipationRequest {
    pub input_vtxos: Vec<InputVtxo>,
    pub vtxo_requests: Vec<VtxoRequest>,
    pub unblinded_mailbox_id: Option<Vec<u8>>,
    pub scheduled_height: Option<u32>,
}

Fields

input_vtxos: Vec<InputVtxo>vtxo_requests: Vec<VtxoRequest>unblinded_mailbox_id: Option<Vec<u8>>

Optional unblinded mailbox identifier for VTXO delivery. The server will post the created VTXO to this mailbox after the round completes.

scheduled_height: Option<u32>

Block height at which the refresh should happen: fees are calculated at this height and no round includes the participation before it. If omitted, the refresh happens in the next round.

Implementations

Source

impl RoundParticipationRequest

pub fn unblinded_mailbox_id(&self) -> &[u8]

Returns the value of unblinded_mailbox_id, or the default value if unblinded_mailbox_id is unset.

pub fn scheduled_height(&self) -> u32

Returns the value of scheduled_height, or the default value if scheduled_height is unset.