pub struct RoundParticipationStatusResponse {
pub status: i32,
pub round_funding_tx: Option<Vec<u8>>,
pub output_vtxos: Vec<Vec<u8>>,
pub unlock_preimage: Option<Vec<u8>>,
}Fields
status: i32the actual status
round_funding_tx: Option<Vec<u8>>signed round funding tx (provided if status != ROUND_PART_PENDING)
output_vtxos: Vec<Vec<u8>>unsigned output vtxos (provided if status != ROUND_PART_PENDING)
unlock_preimage: Option<Vec<u8>>unlock preimage to unlock new vtxos (provided if status == ROUND_PART_RELEASED)
Implementations
Sourceimpl RoundParticipationStatusResponse
impl RoundParticipationStatusResponse
Sourcepub fn status(&self) -> RoundParticipationStatus
pub fn status(&self) -> RoundParticipationStatus
Returns the enum value of status, or the default if the field is set to an invalid enum value.
Sourcepub fn set_status(&mut self, value: RoundParticipationStatus)
pub fn set_status(&mut self, value: RoundParticipationStatus)
Sets status to the provided enum value.
Sourcepub fn round_funding_tx(&self) -> &[u8] ⓘ
pub fn round_funding_tx(&self) -> &[u8] ⓘ
Returns the value of round_funding_tx, or the default value if round_funding_tx is unset.
Sourcepub fn unlock_preimage(&self) -> &[u8] ⓘ
pub fn unlock_preimage(&self) -> &[u8] ⓘ
Returns the value of unlock_preimage, or the default value if unlock_preimage is unset.