pub struct SignedVtxoRequest {
pub vtxo: Option<VtxoRequest>,
pub cosign_pubkey: Vec<u8>,
pub public_nonces: Vec<Vec<u8>>,
}Fields
vtxo: Option<VtxoRequest>cosign_pubkey: Vec<u8>public_nonces: Vec<Vec<u8>>Trait Implementations
Sourceimpl Clone for SignedVtxoRequest
impl Clone for SignedVtxoRequest
Sourcefn clone(&self) -> SignedVtxoRequest
fn clone(&self) -> SignedVtxoRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SignedVtxoRequest
impl Debug for SignedVtxoRequest
Sourceimpl Default for SignedVtxoRequest
impl Default for SignedVtxoRequest
impl Eq for SignedVtxoRequest
Sourceimpl From<SignedVtxoRequest> for SignedVtxoRequest
impl From<SignedVtxoRequest> for SignedVtxoRequest
Sourcefn from(v: SignedVtxoRequest) -> Self
fn from(v: SignedVtxoRequest) -> Self
Converts to this type from the input type.
Sourceimpl Hash for SignedVtxoRequest
impl Hash for SignedVtxoRequest
Sourceimpl Message for SignedVtxoRequest
impl Message for SignedVtxoRequest
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for SignedVtxoRequest
impl PartialEq for SignedVtxoRequest
Sourcefn eq(&self, other: &SignedVtxoRequest) -> bool
fn eq(&self, other: &SignedVtxoRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for SignedVtxoRequest
Sourceimpl TryFrom<SignedVtxoRequest> for SignedVtxoRequest
impl TryFrom<SignedVtxoRequest> for SignedVtxoRequest
Sourcetype Error = ConvertError
type Error = ConvertError
The type returned in the event of a conversion error.