pub struct VtxoRequest {
pub amount: u64,
pub policy: Vec<u8>,
}Fields
amount: u64policy: Vec<u8>Trait Implementations
Sourceimpl Clone for VtxoRequest
impl Clone for VtxoRequest
Sourcefn clone(&self) -> VtxoRequest
fn clone(&self) -> VtxoRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for VtxoRequest
impl Debug for VtxoRequest
Sourceimpl Default for VtxoRequest
impl Default for VtxoRequest
Sourceimpl<'a> From<&'a VtxoRequest> for VtxoRequest
impl<'a> From<&'a VtxoRequest> for VtxoRequest
Sourcefn from(v: &'a VtxoRequest) -> Self
fn from(v: &'a VtxoRequest) -> Self
Converts to this type from the input type.
Sourceimpl Hash for VtxoRequest
impl Hash for VtxoRequest
Sourceimpl Message for VtxoRequest
impl Message for VtxoRequest
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for VtxoRequest
impl PartialEq for VtxoRequest
Sourcefn eq(&self, other: &VtxoRequest) -> bool
fn eq(&self, other: &VtxoRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl TryFrom<VtxoRequest> for VtxoRequest
impl TryFrom<VtxoRequest> for VtxoRequest
Sourcetype Error = ConvertError
type Error = ConvertError
The type returned in the event of a conversion error.
impl Eq for VtxoRequest
impl StructuralPartialEq for VtxoRequest