pub struct WalletStatus {
pub address: String,
pub total_balance: u64,
pub trusted_balance: u64,
pub untrusted_balance: u64,
pub confirmed_utxos: Vec<String>,
pub unconfirmed_utxos: Vec<String>,
}Fields
address: Stringtotal_balance: u64trusted_balance: u64untrusted_balance: u64confirmed_utxos: Vec<String>unconfirmed_utxos: Vec<String>Trait Implementations
Sourceimpl Clone for WalletStatus
impl Clone for WalletStatus
Sourcefn clone(&self) -> WalletStatus
fn clone(&self) -> WalletStatus
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for WalletStatus
impl Debug for WalletStatus
Sourceimpl Default for WalletStatus
impl Default for WalletStatus
Sourceimpl From<WalletStatus> for WalletStatus
impl From<WalletStatus> for WalletStatus
Sourcefn from(s: WalletStatus) -> Self
fn from(s: WalletStatus) -> Self
Converts to this type from the input type.
Sourceimpl Hash for WalletStatus
impl Hash for WalletStatus
Sourceimpl Message for WalletStatus
impl Message for WalletStatus
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for WalletStatus
impl PartialEq for WalletStatus
Sourceimpl TryFrom<WalletStatus> for WalletStatus
impl TryFrom<WalletStatus> for WalletStatus
Sourcetype Error = ConvertError
type Error = ConvertError
The type returned in the event of a conversion error.
impl Eq for WalletStatus
impl StructuralPartialEq for WalletStatus