#[repr(i32)]pub enum TokenStatus {
Unused = 0,
Used = 1,
Abused = 2,
Disabled = 3,
Expired = 4,
}Variants
Unused = 0
The token has not been used.
Used = 1
The token has been used at least once.
Abused = 2
This token has been confirmed as incorrectly used.
Disabled = 3
The token has been disabled.
Expired = 4
This status doesn’t actually exist but is a replacement for:
- (state = UNUSED) && (expires_at < NOW)
- (state = UNUSED) && (expires_after_round >= last_round_seq)
Implementations
Sourceimpl TokenStatus
impl TokenStatus
Sourceimpl TokenStatus
impl TokenStatus
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.