pub struct TokenInfo {
pub token: String,
pub type: i32,
pub status: i32,
pub since: u64,
pub expires_at: u64,
}Fields
token: StringThe actual token.
type: i32The type of token.
status: i32The status of the token.
since: u64Since when this token has this status.
expires_at: u64When the token will expire (Epoch/UNIX time).
Implementations
Sourceimpl TokenInfo
impl TokenInfo
Sourcepub fn type(&self) -> TokenType
pub fn type(&self) -> TokenType
Returns the enum value of type, or the default if the field is set to an invalid enum value.
Sourcepub fn status(&self) -> TokenStatus
pub fn status(&self) -> TokenStatus
Returns the enum value of status, or the default if the field is set to an invalid enum value.
Sourcepub fn set_status(&mut self, value: TokenStatus)
pub fn set_status(&mut self, value: TokenStatus)
Sets status to the provided enum value.