pub struct TokenInfoRequest {
pub api_key: String,
pub token: String,
}Fields
api_key: StringThe API key that was provided to the integrator to use this service in the form of a UUID.
token: StringThe token you want the information for.