pub struct TokensRequest {
pub api_key: String,
pub type: i32,
pub count: Option<u32>,
}Fields
api_key: StringThe API key that was provided to the integrator to use this service in the form of a UUID.
type: i32The type of token you want to generate.
count: Option<u32>The amount of tokens you want (when omitted only 1 will be generated).
Implementations