pub struct UpdateTokenRequest {
pub api_key: String,
pub token: String,
pub status: i32,
}Fields
api_key: StringThe API key that was provided to the integrator to use this service in the form of a UUID.
token: StringThe token you want to update.
status: i32The status you want the token to have.
Implementations
Sourceimpl UpdateTokenRequest
impl UpdateTokenRequest
Sourcepub fn status(&self) -> TokenStatus
pub fn status(&self) -> TokenStatus
Returns the enum value of status, or the default if the field is set to an invalid enum value.
Sourcepub fn set_status(&mut self, value: TokenStatus)
pub fn set_status(&mut self, value: TokenStatus)
Sets status to the provided enum value.