pub struct MailboxRequest {
pub unblinded_id: Vec<u8>,
pub authorization: Option<Vec<u8>>,
pub checkpoint: u64,
}Fields
unblinded_id: Vec<u8>The unblinded mailbox ID to obtain data from
A signed proof that you are allowed to read from this mailbox
checkpoint: u64The last checkpoint you have seen/processed
Implementations
Sourceimpl MailboxRequest
impl MailboxRequest
Returns the value of authorization, or the default value if authorization is unset.